@@ -155,7 +155,10 @@ class CLIParser:
                 "-r",
                 type=str,
                 required=False,
-                help="submit a work requirement definition file in JSON format",
+                help=(
+                    "work requirement definition file in JSON or Jsonnet format"
+                    " (deprecated: please use positional argument instead)"
+                ),
                 metavar="<work_requirement.json>",
             )
             parser.add_argument(
@@ -251,7 +254,10 @@ class CLIParser:
                 "-p",
                 type=str,
                 required=False,
-                help="worker pool definition file in JSON format",
+                help=(
+                    "worker pool definition file in JSON or Jsonnet format"
+                    " (deprecated: please use positional argument instead)"
+                ),
                 metavar="<worker_pool.json>",
             )
 
@@ -365,6 +371,17 @@ class CLIParser:
                     " will be overwritten)"
                 ),
             )
+            parser.add_argument(
+                "--pattern",
+                "-p",
+                type=str,
+                required=False,
+                help=(
+                    "the pattern to use to match objects to be downloaded, "
+                    " e.g.: 'work_dir/results_*/results.txt'"
+                ),
+                metavar="<pattern-string>",
+            )
 
         if "list" in sys.argv[0]:
             parser.add_argument(
@@ -484,6 +501,13 @@ class CLIParser:
                 required=False,
                 help="list compute instances",
             )
+            parser.add_argument(
+                "--allowances",
+                "-A",
+                action="store_true",
+                required=False,
+                help="list allowances",
+            )
 
         if any(module in sys.argv[0] for module in ["upload"]):
             parser.add_argument(
@@ -539,7 +563,10 @@ class CLIParser:
                 "-C",
                 type=str,
                 required=False,
-                help="the compute requirement definition",
+                help=(
+                    "compute requirement definition file in JSON or Jsonnet format"
+                    " (deprecated: please use positional argument instead)"
+                ),
                 metavar="<compute_requirement.json>",
             )
             parser.add_argument(
@@ -869,6 +896,48 @@ class CLIParser:
                 help="the YellowDog ID(s) of the task(s) to abort",
             )
 
+        if any(module in sys.argv[0] for module in ["submit"]):
+            # Note: removes the need for the '-r' option
+            parser.add_argument(
+                "work_requirement_file_positional",
+                metavar="<work-requirement-specification-file>",
+                type=str,
+                nargs="?",
+                help=(
+                    "the JSON or Jsonnet specification of the work requirement"
+                    " to submit; alternative to using the '--work-requirement/-r'"
+                    " option"
+                ),
+            )
+
+        if any(module in sys.argv[0] for module in ["provision"]):
+            # Note: removes the need for the '-p' option
+            parser.add_argument(
+                "worker_pool_file_positional",
+                metavar="<worker-pool-specification-file>",
+                type=str,
+                nargs="?",
+                help=(
+                    "the JSON or Jsonnet specification of the worker pool"
+                    " to provision; alternative to using the '--worker-pool/-p'"
+                    " option"
+                ),
+            )
+
+        if any(module in sys.argv[0] for module in ["instantiate"]):
+            # Note: removes the need for the '-C' option
+            parser.add_argument(
+                "compute_requirement_file_positional",
+                metavar="<compute-requirement-specification-file>",
+                type=str,
+                nargs="?",
+                help=(
+                    "the JSON or Jsonnet specification of the compute requirement"
+                    " to provision; alternative to using the"
+                    "'--compute-requirement/-C' option"
+                ),
+            )
+
         self.args = parser.parse_args()
 
         if self.args.docs:
@@ -1179,6 +1248,11 @@ class CLIParser:
     def instances(self) -> Optional[bool]:
         return self.args.instances
 
+    @property
+    @allow_missing_attribute
+    def allowances(self) -> Optional[bool]:
+        return self.args.allowances
+
     @property
     @allow_missing_attribute
     def show_keyring_passwords(self) -> Optional[bool]:
@@ -1254,6 +1328,26 @@ class CLIParser:
     def task_id_list(self) -> Optional[List[str]]:
         return self.args.task_id_list
 
+    @property
+    @allow_missing_attribute
+    def work_requirement_file_positional(self) -> Optional[str]:
+        return self.args.work_requirement_file_positional
+
+    @property
+    @allow_missing_attribute
+    def worker_pool_file_positional(self) -> Optional[str]:
+        return self.args.worker_pool_file_positional
+
+    @property
+    @allow_missing_attribute
+    def compute_requirement_file_positional(self) -> Optional[str]:
+        return self.args.compute_requirement_file_positional
+
+    @property
+    @allow_missing_attribute
+    def object_path_pattern(self) -> Optional[str]:
+        return self.args.pattern
+
 
 def lookup_module_description(module_name: str) -> Optional[str]:
     """
