@@ -1,15 +1,16 @@
 """
-Configuration key strings
+Property names.
 """
 
+ADD_YD_ENV_VARS = "addYDEnvironmentVariables"
 ALWAYS_UPLOAD = "alwaysUpload"  # Bool
 ARGS = "arguments"  # List
-CAPTURE_TASKOUTPUT = "captureTaskOutput"  # Bool
 COMMON_SECTION = "common"  # No value
 COMPLETED_TASK_TTL = "completedTaskTtl"  # Float
 COMPUTE_REQUIREMENT_BATCH_SIZE = "computeRequirementBatchSize"  # Integer
 COMPUTE_REQUIREMENT_DATA_FILE = "computeRequirementData"  # String
 COMPUTE_REQUIREMENT_SECTION = "computeRequirement"  # No value
+CR_TAG = "requirementTag"  # String
 CSV_FILE = "csvFile"  # String
 CSV_FILES = "csvFiles"  # List of Strings
 DEPENDENT_ON = "dependentOn"  # String
@@ -17,6 +18,7 @@ DIRECTORY_NAME = "directoryName"  # String
 DOCKER_ENV = "dockerEnvironment"  # Dictionary
 DOCKER_OPTIONS = "dockerOptions"  # List
 DOCKER_PASSWORD = "dockerPassword"  # String
+DOCKER_REGISTRY = "dockerRegistry"  # String
 DOCKER_USERNAME = "dockerUsername"  # String
 ENV = "environment"  # Dictionary
 EXCLUSIVE_WORKERS = "exclusiveWorkers"  # Boolean
@@ -26,10 +28,10 @@ FINISH_IF_ALL_TASKS_FINISHED = "finishIfAllTasksFinished"  # Boolean
 FINISH_IF_ANY_TASK_FAILED = "finishIfAnyTaskFailed"  # Boolean
 FLATTEN_PATHS = "flattenInputPaths"  # Boolean
 FLATTEN_UPLOAD_PATHS = "flattenUploadPaths"  # Boolean
-IDLE_NODE_SHUTDOWN_TIMEOUT = "idleNodeShutdownTimeout"  # Float
-IDLE_POOL_SHUTDOWN_TIMEOUT = "idlePoolShutdownTimeout"  # Float
+IDLE_NODE_TIMEOUT = "idleNodeTimeout"  # Float
+IDLE_POOL_TIMEOUT = "idlePoolTimeout"  # Float
 IMAGES_ID = "imagesId"  # String
-IMPORT = "import"  # String
+IMPORT_COMMON = "importCommon"  # String
 INPUTS_OPTIONAL = "inputsOptional"  # List of Strings
 INPUTS_REQUIRED = "inputs"  # List of Strings
 INSTANCE_TAGS = "instanceTags"  # List of Strings
@@ -64,14 +66,17 @@ TASK_DATA = "taskData"  # String
 TASK_DATA_FILE = "taskDataFile"  # String
 TASK_GROUPS = "taskGroups"  # List of Task Groups
 TASK_GROUP_NAME = "taskGroupName"  # String
-TASK_NAME = "taskName"  # String
-TASK_TIMEOUT = "taskTimeout"  # Float
+TASK_GROUP_TAG = "tag"  # String
 TASK_LEVEL_TIMEOUT = "timeout"  # Float
+TASK_NAME = "taskName"  # String
+TASK_TAG = "tag"  # String
+TASK_TIMEOUT = "taskTimeout"  # Float
 TASK_TYPE = "taskType"  # String
 TASK_TYPES = "taskTypes"  # List of Strings
 TEMPLATE_ID = "templateId"  # String
 UPLOAD_FILES = "uploadFiles"  # List of Dicts
 UPLOAD_PATH = "uploadPath"  # String
+UPLOAD_TASKOUTPUT = "uploadTaskProcessOutput"  # Bool
 URL = "url"  # String
 USERDATA = "userData"  # String
 USERDATAFILE = "userDataFile"  # String
@@ -91,16 +96,18 @@ WORK_REQUIREMENT_SECTION = "workRequirement"  # No value
 WP_NAME = "name"  # String
 WR_DATA = "workRequirementData"  # String
 WR_NAME = "name"  # String
+WR_TAG = "tag"  # String
 
 ALL_KEYS = [
+    ADD_YD_ENV_VARS,
     ALWAYS_UPLOAD,
     ARGS,
-    CAPTURE_TASKOUTPUT,
     COMMON_SECTION,
     COMPLETED_TASK_TTL,
     COMPUTE_REQUIREMENT_BATCH_SIZE,
     COMPUTE_REQUIREMENT_DATA_FILE,
     COMPUTE_REQUIREMENT_SECTION,
+    CR_TAG,
     CSV_FILE,
     CSV_FILES,
     DEPENDENT_ON,
@@ -108,6 +115,7 @@ ALL_KEYS = [
     DOCKER_ENV,
     DOCKER_OPTIONS,
     DOCKER_PASSWORD,
+    DOCKER_REGISTRY,
     DOCKER_USERNAME,
     ENV,
     EXCLUSIVE_WORKERS,
@@ -117,10 +125,10 @@ ALL_KEYS = [
     FINISH_IF_ANY_TASK_FAILED,
     FLATTEN_PATHS,
     FLATTEN_UPLOAD_PATHS,
-    IDLE_NODE_SHUTDOWN_TIMEOUT,
-    IDLE_POOL_SHUTDOWN_TIMEOUT,
+    IDLE_NODE_TIMEOUT,
+    IDLE_POOL_TIMEOUT,
     IMAGES_ID,
-    IMPORT,
+    IMPORT_COMMON,
     INPUTS_OPTIONAL,
     INPUTS_REQUIRED,
     INSTANCE_TAGS,
@@ -154,14 +162,17 @@ ALL_KEYS = [
     TASK_DATA_FILE,
     TASK_GROUPS,
     TASK_GROUP_NAME,
-    TASK_NAME,
-    TASK_TIMEOUT,
+    TASK_GROUP_TAG,
     TASK_LEVEL_TIMEOUT,
+    TASK_NAME,
+    TASK_TAG,
+    TASK_TIMEOUT,
     TASK_TYPE,
     TASK_TYPES,
     TEMPLATE_ID,
     UPLOAD_FILES,
     UPLOAD_PATH,
+    UPLOAD_TASKOUTPUT,
     URL,
     USERDATA,
     USERDATAFILE,
@@ -181,4 +192,5 @@ ALL_KEYS = [
     WP_NAME,
     WR_DATA,
     WR_NAME,
+    WR_TAG,
 ]
