@@ -83,7 +83,7 @@ if ARGS_PARSER.variables is not None:
             exit(1)  # Note: exception trap not yet in place
 
 
-def add_substitutions(subs: Dict):
+def add_substitutions_without_overwriting(subs: Dict):
     """
     Add a dictionary of substitutions. Do not overwrite existing values, but
     resolve remaining variables if possible.
@@ -98,7 +98,7 @@ def add_substitutions(subs: Dict):
         VARIABLE_SUBSTITUTIONS[key] = process_variable_substitutions(str(value))
 
 
-def add_substitution_overwrite(key: str, value: str):
+def add_or_update_substitution(key: str, value: str):
     """
     Add a substitution to the dictionary, overwriting existing values.
     """
@@ -356,14 +356,25 @@ def process_typed_variable_substitution(
             )
 
 
+def resolve_filename(files_directory: str, filename: str) -> str:
+    """
+    Check whether 'files_directory' is redundant.
+    This is a suboptimal approach, but works for now.
+    """
+    if os.path.dirname(os.path.abspath(filename)) == os.path.abspath(files_directory):
+        return filename
+    else:
+        return os.path.join(files_directory, filename)
+
+
 def load_json_file_with_variable_substitutions(
-    filename: str, prefix: str = "", postfix: str = ""
+    filename: str, prefix: str = "", postfix: str = "", files_directory: str = ""
 ) -> Dict:
     """
     Takes a JSON filename and returns a dictionary with its variable
     substitutions processed.
     """
-    with open(filename, "r") as f:
+    with open(resolve_filename(files_directory, filename), "r") as f:
         file_contents = f.read()
     file_contents = process_variable_substitutions_in_file_contents(
         file_contents, prefix=prefix, postfix=postfix
@@ -372,7 +383,11 @@ def load_json_file_with_variable_substitutions(
 
 
 def load_jsonnet_file_with_variable_substitutions(
-    filename: str, prefix: str = "", postfix: str = ""
+    filename: str,
+    prefix: str = "",
+    postfix: str = "",
+    files_directory: str = "",
+    exit_on_dry_run=True,
 ) -> Dict:
     """
     Takes a Jsonnet filename and returns a dictionary with its variable
@@ -382,37 +397,44 @@ def load_jsonnet_file_with_variable_substitutions(
     from _jsonnet import evaluate_file
 
     with VariableSubstitutedJsonnetFile(
-        filename=filename, prefix=prefix, postfix=postfix
+        filename=resolve_filename(files_directory, filename),
+        prefix=prefix,
+        postfix=postfix,
     ) as preprocessed_filename:
-        dict_data = json_loads(evaluate_file(preprocessed_filename))
+        try:
+            dict_data = json_loads(evaluate_file(preprocessed_filename))
+        except RuntimeError as e:
+            # Include only the first line of the exception message
+            raise Exception(str(e).partition("\n")[0])
 
     # Secondary processing after Jsonnet expansion
     process_variable_substitutions_insitu(dict_data, prefix, postfix)
 
     if ARGS_PARSER.jsonnet_dry_run:
-        print_log("Dry-run: Printing Jsonnet to JSON conversion")
+        print_log(f"Dry-run: Printing Jsonnet to JSON conversion for '{filename}'")
         print_json(dict_data)
-        print_log("Dry run: Complete")
-        exit(0)
+        print_log("Dry-run: Complete")
+        if exit_on_dry_run:
+            sys.exit(0)
 
     return dict_data
 
 
 def load_toml_file_with_variable_substitutions(
-    filename: str, prefix: str = "", postfix: str = ""
+    filename: str, prefix: str = "", postfix: str = "", files_directory: str = ""
 ) -> Dict:
     """
     Takes a TOML filename and returns a dictionary with its variable
     substitutions processed.
     """
-    with open(filename, "r") as f:
+    with open(resolve_filename(files_directory, filename), "r") as f:
         config = toml_load(f)
 
     # Add any variable substitutions in the TOML file before processing the
     # file as a whole
     try:
         # Convert all values to strings before adding
-        add_substitutions({
+        add_substitutions_without_overwriting({
             var_name: str(var_value)
             for var_name, var_value in config[COMMON_SECTION][VARIABLES].items()
         })
@@ -483,7 +505,9 @@ class VariableSubstitutedJsonnetFile:
         processed_file_contents: str = process_variable_substitutions_in_file_contents(
             file_contents, self.prefix, self.postfix
         )
-        with tempfile.NamedTemporaryFile(mode="w", delete=False) as temp_file:
+        with tempfile.NamedTemporaryFile(
+            mode="w", delete=False, dir=os.getcwd()
+        ) as temp_file:
             temp_file.write(processed_file_contents)
         self.temp_filename: str = temp_file.name
         return self.temp_filename
